==> dokuwiki-2020.07.29p0.tgz: dokuwiki/lib/plugins/authad/lang/fr/settings.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Schplurtz le Déboulonné <schplurtz@laposte.net>
 * @author Bruno Veilleux <bruno.vey@gmail.com>
 * @author Momo50 <c.brothelande@gmail.com>
 */
$lang['account_suffix']        = 'Le suffixe de votre compte. Ex.: <code>@mon.domaine.org</code>';
$lang['base_dn']               = 'Votre nom de domaine de base. <code>DC=mon,DC=domaine,DC=org</code>';
$lang['domain_controllers']    = 'Une liste de contrôleurs de domaine séparés par des virgules. Ex.: <code>srv1.domaine.org,srv2.domaine.org</code>';
$lang['admin_username']        = 'Un utilisateur Active Directory avec accès aux données de tous les autres utilisateurs. Facultatif, mais nécessaire pour certaines actions telles que l\'envoi de courriels d\'abonnement.';
$lang['admin_password']        = 'Le mot de passe de l\'utilisateur ci-dessus.';
$lang['sso']                   = 'Est-ce que l\'authentification unique (Single-Sign-On) par Kerberos ou NTLM doit être utilisée?';
$lang['sso_charset']           = 'Le jeu de caractères de votre serveur web va passer le nom d\'utilisateur Kerberos ou NTLM. Vide pour UTF-8 ou latin-1. Nécessite l\'extension iconv.';
$lang['real_primarygroup']     = 'Est-ce que le véritable groupe principal doit être résolu au lieu de présumer "Domain Users" (plus lent)?';
$lang['use_ssl']               = 'Utiliser une connexion SSL? Si utilisée, n\'activez pas TLS ci-dessous.';
$lang['use_tls']               = 'Utiliser une connexion TLS? Si utilisée, n\'activez pas SSL ci-dessus.';
$lang['debug']                 = 'Afficher des informations de débogage supplémentaires pour les erreurs?';
$lang['expirywarn']            = 'Jours d\'avance pour l\'avertissement envoyé aux utilisateurs lorsque leur mot de passe va expirer. 0 pour désactiver.';
$lang['additional']            = 'Une liste séparée par des virgules d\'attributs AD supplémentaires à récupérer dans les données utilisateur. Utilisée par certains modules.';
$lang['update_name']           = 'Autoriser les utilisateurs à modifier leur nom affiché de l\'AD ?';
$lang['update_mail']           = 'Autoriser les utilisateurs à modifier leur adresse de courriel ?';
$lang['recursive_groups']      = 'Résoudre les groupes imbriqués à leur membres respectifs (plus lent).';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/authad/lang/fr/settings.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Olivier Humbert <trebmuh@tuxfamily.org>
 * @author Philippe Verbeke <ph.verbeke@gmail.com>
 * @author Schplurtz le Déboulonné <schplurtz@laposte.net>
 * @author Bruno Veilleux <bruno.vey@gmail.com>
 * @author Momo50 <c.brothelande@gmail.com>
 */
$lang['account_suffix']        = 'Le suffixe de votre compte. Ex. : <code>@mon.domaine.org</code>';
$lang['base_dn']               = 'Votre nom de domaine de base. <code>DC=mon,DC=domaine,DC=org</code>';
$lang['domain_controllers']    = 'Une liste de contrôleurs de domaine séparés par des virgules. Ex. : <code>srv1.domaine.org,srv2.domaine.org</code>';
$lang['admin_username']        = 'Un utilisateur Active Directory avec accès aux données de tous les autres utilisateurs. Facultatif, mais nécessaire pour certaines actions telles que l\'envoi de courriels d\'abonnement.';
$lang['admin_password']        = 'Le mot de passe de l\'utilisateur ci-dessus.';
$lang['sso']                   = 'Est-ce que l\'authentification unique (Single-Sign-On) par Kerberos ou NTLM doit être utilisée?';
$lang['sso_charset']           = 'Le jeu de caractères que votre serveur web utilisera pour transmettre le nom d\'utilisateur Kerberos ou NTLM. Vide pour UTF-8 ou latin-1. Nécessite l\'extension iconv.';
$lang['real_primarygroup']     = 'Est-ce que le véritable groupe principal doit être résolu au lieu de présumer "Domain Users" (plus lent)?';
$lang['use_ssl']               = 'Utiliser une connexion SSL? Si utilisée, n\'activez pas TLS ci-dessous.';
$lang['use_tls']               = 'Utiliser une connexion TLS? Si utilisée, n\'activez pas SSL ci-dessus.';
$lang['debug']                 = 'Afficher des informations de débogage supplémentaires pour les erreurs?';
$lang['expirywarn']            = 'Jours d\'avance pour l\'avertissement envoyé aux utilisateurs lorsque leur mot de passe va expirer. 0 pour désactiver.';
$lang['additional']            = 'Une liste séparée par des virgules d\'attributs AD supplémentaires à récupérer dans les données utilisateur. Utilisée par certains modules.';
$lang['update_name']           = 'Autoriser les utilisateurs à modifier leur nom affiché de l\'AD ?';
$lang['update_mail']           = 'Autoriser les utilisateurs à modifier leur adresse de courriel ?';
$lang['update_pass']           = 'Autoriser les utilisateurs à mettre à jour leur mot de passe ? Nécessite SSL ou TLS ci-dessus.';
$lang['recursive_groups']      = 'Résoudre les groupes imbriqués à leur membres respectifs (plus lent).';
